@@ -1,5 +1,7 @@
 import mcpi
 
+from mcpi.vec3 import Vec3
+
 from .thing import Thing
 
 
@@ -17,3 +19,6 @@ class BlocksGallery(Thing):
         for i in range(1, self.MAX_BLOCK_NUMBER):
             self.server.setBlock(self.position.x + i, self.position.y,
                                  self.position.z, mcpi.block.Block(i))
+
+        self._end_position = Vec3(self.position.x + self.MAX_BLOCK_NUMBER - 1,
+                                  self.position.y, self.position.z)
